@@ -11,7 +11,6 @@ A `MessagePump` is a base class for any object which processes messages, which i
 from __future__ import annotations
 
 import asyncio
-import inspect
 import threading
 from asyncio import CancelledError, Queue, QueueEmpty, Task, create_task
 from contextlib import contextmanager
@@ -36,7 +35,6 @@ from ._context import message_hook as message_hook_context_var
 from ._context import prevent_message_types_stack
 from ._on import OnNoWidget
 from ._time import time
-from .case import camel_to_snake
 from .css.match import match
 from .errors import DuplicateKeyHandlers
 from .events import Event
@@ -78,8 +76,6 @@ class _MessagePumpMeta(type):
         class_dict: dict[str, Any],
         **kwargs: Any,
     ) -> _MessagePumpMetaSub:
-        namespace = camel_to_snake(name)
-        isclass = inspect.isclass
         handlers: dict[
             type[Message], list[tuple[Callable, dict[str, tuple[SelectorSet, ...]]]]
         ] = class_dict.get("_decorated_handlers", {})
@@ -93,13 +89,6 @@ class _MessagePumpMeta(type):
                 ] = getattr(value, "_textual_on")
                 for message_type, selectors in textual_on:
                     handlers.setdefault(message_type, []).append((value, selectors))
-            if isclass(value) and issubclass(value, Message):
-                if "namespace" in value.__dict__:
-                    value.handler_name = f"on_{value.__dict__['namespace']}_{camel_to_snake(value.__name__)}"
-                else:
-                    value.handler_name = (
-                        f"on_{namespace}_{camel_to_snake(value.__name__)}"
-                    )
 
         # Look for reactives with public AND private compute methods.
         prefix = "compute_"
@@ -258,9 +247,8 @@ class MessagePump(metaclass=_MessagePumpMeta):
     @property
     def is_parent_active(self) -> bool:
         """Is the parent active?"""
-        return bool(
-            self._parent and not self._parent._closed and not self._parent._closing
-        )
+        parent = self._parent
+        return bool(parent is not None and not parent._closed and not parent._closing)
 
     @property
     def is_running(self) -> bool:
@@ -297,6 +285,7 @@ class MessagePump(metaclass=_MessagePumpMeta):
         Returns:
             `True` if the message will be sent, or `False` if it is disabled.
         """
+
         return type(message) not in self._disabled_messages
 
     def disable_messages(self, *messages: type[Message]) -> None:
